@@ -7,7 +7,7 @@ module External (
     signString, verifyPS,
     execPipeIgnoreError,
     getTermNColors,
-    pipeDoc_SSH_IgnoreError,
+    pipeDoc_SSH_IgnoreError, execSSH,
     maybeURLCmd,
     Cachable(Cachable, Uncachable, MaxAge)
   ) where
@@ -18,8 +18,8 @@ import System ( ExitCode(..), system, getEnv )
 import IO ( hPutStr, hPutStrLn, hClose, hFlush, try, stdout )
 import System.IO.Error ( isDoesNotExistError )
 import System.IO.Unsafe ( unsafePerformIO )
-import System.Posix ( getSymbolicLinkStatus, isRegularFile, isDirectory )
-import System.Directory ( createDirectory, getDirectoryContents )
+import System.Posix.Files ( getSymbolicLinkStatus, isRegularFile, isDirectory )
+import System.Directory ( createDirectory, getDirectoryContents, doesFileExist )
 import Char ( toUpper )
 import Foreign.C ( CString, withCString, CInt )
 import Foreign.Ptr ( nullPtr )
@@ -31,6 +31,7 @@ import Autoconf ( use_color )
 #endif
 import Workaround ( createLink, createDirectoryIfMissing )
 
+import AtExit ( atexit )
 import DarcsFlags ( DarcsFlag( Quiet, SignAs, Sign, SignSSL,
                                Verbose, Verify, VerifySSL ) )
 import DarcsUtils ( withCurrentDirectory )
@@ -40,7 +41,8 @@ import FastPackedString ( PackedString, readFilePS, gzReadFilePS, writeFilePS,
                           nullPS, nilPS, concatPS
                         )
 import Lock ( withTemp, withOpenTemp, readDocBinFile,
-              canonFilename, writeBinFile, writeDocBinFile
+              canonFilename, writeBinFile, writeDocBinFile,
+              tempdir_loc,
             )
 import CommandLine ( parseCmd, addUrlencoded )
 import Autoconf ( have_libcurl, have_sendmail, have_mapi, sendmail_path, darcs_version )
@@ -161,13 +163,9 @@ copyRemoteNormal u v cache = if have_libcurl
                        else copyRemoteCmd u v
 
 copySSH :: String -> FilePath -> IO ()
-copySSH u f = do p <- try $ getEnv "SSH_PORT" -- or DARCS_SSH_PORT ?
-                 scp_command <- getEnv "DARCS_SCP" `catch`
-                                \_ -> return "scp"
-                 let port = either (const []) (\x->["-P",x]) p
-                     scp = head $ words scp_command
-                     scp_args = tail $ words scp_command
-                 r <- exec scp (scp_args++port++[escape_dollar u,f])
+copySSH uRaw f = let u = escape_dollar uRaw in do
+                 (scp, scp_args) <- getSSH SCP u
+                 r <- exec scp (scp_args++[u,f])
                       "/dev/null" "/dev/null"
                  when (r /= ExitSuccess) $
                       fail $ "(scp) failed to fetch: " ++ u
@@ -251,13 +249,8 @@ wgetRemotes u ns d = do wget_command <- getEnv "DARCS_WGET" `catch`
                                               "source files:"] ++ ns
 
 copySSHs :: String -> [String] -> FilePath -> IO ()
-copySSHs u ns d = do p <- try $ getEnv "SSH_PORT" -- or DARCS_SSH_PORT ?
-                     sftp_command <- getEnv "DARCS_SFTP" `catch`
-                                     \_ -> return "sftp"
-                     let port = either (const []) (\x->["-oPort="++x]) p
-                         sftp = head $ words sftp_command
-                         sftp_args = port ++ tail (words sftp_command)
-                         path = drop 1 $ dropWhile (/= ':') u
+copySSHs u ns d = do (sftp, sftp_args) <- getSSH SFTP u
+                     let path = drop 1 $ dropWhile (/= ':') u
                          host = (takeWhile (/= ':') u)++":"
                          cd = "cd "++path++"\n"
                          input = cd++(unlines $ map ("get "++) ns)
@@ -341,17 +334,17 @@ get_ext_cmd' = try_cmd cmds
             return f
            `catch` (\_ -> try_cmd cs)
 
+-- | Run a command on a remote location without passing it any input or
+--   reading its output.  Return its ExitCode
+execSSH :: String -> String -> IO ExitCode
+execSSH remoteAddr command =
+    do (ssh, ssh_args) <- getSSH SSH remoteAddr
+       exec ssh (remoteAddr:ssh_args++[command]) "/dev/null" "/dev/null"
 
-pipeDoc_SSH_IgnoreError :: [String] -> Doc -> IO Doc
-pipeDoc_SSH_IgnoreError args input =
-    do p <- try $ getEnv "SSH_PORT" -- or DARCS_SSH_PORT ?
-       ssh_command <- getEnv "DARCS_SSH" `catch`
-                      \_ -> return "ssh"
-       let port = either (const []) (\x->["-p",x]) p
-           ssh = head $ words ssh_command
-           ssh_args = tail $ words ssh_command
-       execPipeIgnoreError ssh (ssh_args++port++args) input
-
+pipeDoc_SSH_IgnoreError :: String -> [String] -> Doc -> IO Doc
+pipeDoc_SSH_IgnoreError remoteAddr args input =
+    do (ssh, ssh_args) <- getSSH SSH remoteAddr
+       execPipeIgnoreError ssh (ssh_args++ (remoteAddr:args)) input
 
 sendEmail :: String -> String -> String -> String -> String -> String -> IO ()
 sendEmail _ "" _ "" _ _ = return ()
@@ -473,7 +466,7 @@ execSendmail ftable scmd fn =
   else case parseCmd (addUrlencoded ftable) scmd of
          Right (arg0:opts, wantstdin) ->
            do let stdin = if wantstdin then fn else "/dev/null"
-              exec arg0 opts stdin "/dev/nulll"
+              exec arg0 opts stdin "/dev/null"
          Left e -> fail $ ("failed to send mail, invalid sendmail-command: "++(show e))
          _ -> fail $ ("failed to send mail, invalid sendmail-command")
 
@@ -559,7 +552,7 @@ verifyGPG goodkeys s =
       hPutPS th s
       hClose th
       rval <- exec "gpg"  ["--batch","--no-default-keyring",
-                           "--keyring",goodkeys, "--verify"] tn "/dev/null"
+                           "--keyring",fix_path goodkeys, "--verify"] tn "/dev/null"
       case rval of
           ExitSuccess -> return $ Just gpg_fixed_s
           _ -> return Nothing
@@ -572,6 +565,12 @@ verifyGPG goodkeys s =
             fix_line x | lengthPS x < 3 = x
                        | takePS 3 x == packString "- -" = dropPS 2 x
                        | otherwise = x
+#if defined(WIN32)
+            fix_sep c | c=='/' = '\\'   | otherwise = c
+            fix_path p = map fix_sep p
+#else
+            fix_path p = p
+#endif
 
 verifySSL :: FilePath -> PackedString -> IO (Maybe PackedString)
 verifySSL goodkeys s = do
@@ -639,3 +638,105 @@ getTermNColors = return (-1)
 
 #endif
 
+-- ---------------------------------------------------------------------
+-- ssh helper functions
+-- ---------------------------------------------------------------------
+
+data SSHCmd = SSH | SCP | SFTP
+
+instance Show SSHCmd where
+  show SSH  = "ssh"
+  show SCP  = "scp"
+  show SFTP = "sftp"
+
+-- | Return the command and arguments needed to run an ssh command
+--   along with any extra features like use of the control master.
+--   See 'getSSHOnly'
+getSSH :: SSHCmd -> String -- ^ remote path
+       -> IO (String, [String])
+getSSH cmd remoteAddr =
+ do (ssh, ssh_args) <- getSSHOnly cmd
+    -- control master
+    cmPath <- controlMasterPath remoteAddr
+    hasLaunchedCm <- doesFileExist cmPath
+    when (not hasLaunchedCm) $ launchSSHControlMaster remoteAddr
+    hasCmFeature <- doesFileExist cmPath
+    let cm_args = if hasCmFeature then [ "-o ControlPath=" ++ cmPath ] else []
+    --
+    return (ssh, ssh_args ++ cm_args)
+
+-- | Return the command and arguments needed to run an ssh command.
+--   First try the appropriate darcs environment variable and SSH_PORT
+--   defaulting to "ssh" and no specified port.
+getSSHOnly :: SSHCmd -> IO (String, [String])
+getSSHOnly cmd =
+ do ssh_command <- getEnv (evar cmd) `catch`
+                      \_ -> return $ show cmd
+    -- port
+    p <- try $ getEnv "SSH_PORT" -- or DARCS_SSH_PORT ?
+    let port = either (const []) (portFlag cmd) p
+        ssh = head $ words ssh_command
+        ssh_args = tail $ words ssh_command
+    --
+    return (ssh, ssh_args ++ port)
+    where
+     evar SSH  = "DARCS_SSH"
+     evar SCP  = "DARCS_SCP"
+     evar SFTP = "DARCS_SFTP"
+     portFlag SSH  x = ["-p", x]
+     portFlag SCP  x = ["-P", x]
+     portFlag SFTP x = ["-oPort="++x]
+
+-- | Return True if this version of ssh has a ControlMaster feature
+-- The ControlMaster functionality allows for ssh multiplexing
+hasSSHControlMaster :: Bool
+hasSSHControlMaster = unsafePerformIO hasSSHControlMasterIO
+
+-- Because of the unsafePerformIO above, this can be called at any
+-- point.  It cannot rely on any state, not even the current directory.
+hasSSHControlMasterIO :: IO Bool
+hasSSHControlMasterIO = do
+  (ssh, _) <- getSSHOnly SSH
+  -- If ssh has the ControlMaster feature, it will recognise the
+  -- the -O flag, but exit with status 255 because of the nonsense
+  -- command.  If it does not have the feature, it will simply dump
+  -- a help message on the screen and exit with 1.
+  sx <- exec ssh ["-O", "an_invalid_command"] "/dev/null" "/dev/null"
+  case sx of
+    ExitFailure 255 -> return True
+    _ -> return False
+
+-- | Launch an SSH control master in the background, if available.
+--   We don't have to wait for it or anything.
+--   Note also that this will cleanup after itself when darcs exits
+launchSSHControlMaster :: String -> IO ()
+launchSSHControlMaster rawAddr =
+  when hasSSHControlMaster $ do
+  let addr = takeWhile (/= ':') rawAddr
+  (ssh, ssh_args) <- getSSHOnly SSH
+  cmPath <- controlMasterPath addr
+  -- -f : put ssh in the background once it succeeds in logging you in
+  -- -M : launch as the control master for addr
+  -- -N : don't run any commands
+  -- -S : use cmPath as the ControlPath.  Equivalent to -oControlPath=
+  exec ssh (ssh_args ++ [addr, "-S", cmPath, "-N", "-f", "-M"]) "/dev/null" "/dev/null"
+  atexit $ exitSSHControlMaster addr
+  return ()
+
+-- | Tell the SSH control master for a given path to exit.
+exitSSHControlMaster :: String -> IO ()
+exitSSHControlMaster addr = do
+  (ssh, ssh_args) <- getSSHOnly SSH
+  cmPath <- controlMasterPath addr
+  exec ssh (ssh_args ++ [addr, "-S", cmPath, "-O", "exit"]) "/dev/null" "/dev/null"
+  return ()
+
+-- | Create the directory ssh control master path for a given address
+controlMasterPath :: String -- ^ remote path (foo@bar.com:file is ok; the file part with be stripped)
+                  -> IO FilePath
+controlMasterPath rawAddr = do
+  let addr = takeWhile (/= ':') rawAddr
+  tmp <- tempdir_loc
+  let tmpDarcsSsh = tmp ++ "darcs-ssh"
+  createDirectoryIfMissing False tmpDarcsSsh
+  return $ tmpDarcsSsh ++ "/" ++ addr
