@@ -4,8 +4,8 @@
 
 $key = q/{displaymath}A^{-1}ClongleftrightarrowC'A'^{-1}{displaymath};MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="28" HEIGHT="36" BORDER="0"
- SRC="|."$dir".q|img23.png"
+ WIDTH="128" HEIGHT="24" BORDER="0"
+ SRC="|."$dir".q|img24.png"
  ALT="\begin{displaymath}
 A^{ -1} C \longleftrightarrow C' A'^{ -1}
 \end{displaymath}">|; 
@@ -18,135 +18,141 @@ $cached_env_img{$key} = q|<IMG
 
 $key = q/P_1^{-1};MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="36" HEIGHT="36" ALIGN="MIDDLE" BORDER="0"
- SRC="|."$dir".q|img22.png"
+ WIDTH="33" HEIGHT="36" ALIGN="MIDDLE" BORDER="0"
+ SRC="|."$dir".q|img23.png"
  ALT="$P_1^{ -1}$">|; 
 
 $key = q/{displaymath}P_2P_1longleftrightarrow{P_1}'{P_2}'.{displaymath};MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="146" HEIGHT="28" BORDER="0"
- SRC="|."$dir".q|img11.png"
+ WIDTH="120" HEIGHT="26" BORDER="0"
+ SRC="|."$dir".q|img12.png"
  ALT="\begin{displaymath}P_2 P_1 \longleftrightarrow {P_1}' {P_2}'. \end{displaymath}">|; 
 
 $key = q/==;MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="32" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
- SRC="|."$dir".q|img15.png"
+ WIDTH="28" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
+ SRC="|."$dir".q|img16.png"
  ALT="$==$">|; 
 
 $key = q/{displaymath}P_2parallelP_1Longrightarrow{P_2}'P_1longleftrightarrow{P_1}'P_2.{displaymath};MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="24" HEIGHT="15" BORDER="0"
- SRC="|."$dir".q|img18.png"
+ WIDTH="206" HEIGHT="28" BORDER="0"
+ SRC="|."$dir".q|img19.png"
  ALT="\begin{displaymath}P_2 \parallel P_1 \Longrightarrow {P_2}' P_1 \longleftrightarrow {P_1}' P_2. \end{displaymath}">|; 
 
 $key = q/(P^{-1}P);MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="15" HEIGHT="14" ALIGN="BOTTOM" BORDER="0"
- SRC="|."$dir".q|img9.png"
+ WIDTH="45" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
+ SRC="|."$dir".q|img10.png"
  ALT="\( P^{ -1} P \)">|; 
 
 $key = q/O(n);MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="342" HEIGHT="22" ALIGN="MIDDLE" BORDER="0"
- SRC="|."$dir".q|img24.png"
+ WIDTH="38" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
+ SRC="|."$dir".q|img25.png"
  ALT="$O(n)$">|; 
 
 $key = q/P^{-1};MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="55" HEIGHT="32" ALIGN="BOTTOM" BORDER="0"
- SRC="|."$dir".q|img7.png"
+ WIDTH="33" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
+ SRC="|."$dir".q|img8.png"
  ALT="$P^{ -1}$">|; 
 
 $key = q/P_2'P_1longleftrightarrowP_1'P_2;MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="381" HEIGHT="26" ALIGN="MIDDLE" BORDER="0"
- SRC="|."$dir".q|img19.png"
+ WIDTH="110" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
+ SRC="|."$dir".q|img20.png"
  ALT="$ P_2' P_1 \longleftrightarrow P_1' P_2 $">|; 
 
 $key = q/P_2';MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
  WIDTH="20" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
- SRC="|."$dir".q|img13.png"
+ SRC="|."$dir".q|img14.png"
  ALT="$P_2'$">|; 
 
 $key = q/P_2;MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
  WIDTH="20" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
- SRC="|."$dir".q|img4.png"
+ SRC="|."$dir".q|img5.png"
  ALT="$P_2$">|; 
 
 $key = q/P;MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="33" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
- SRC="|."$dir".q|img8.png"
+ WIDTH="15" HEIGHT="14" ALIGN="BOTTOM" BORDER="0"
+ SRC="|."$dir".q|img9.png"
  ALT="$P$">|; 
 
+$key = q/+;MSF=1.6;AAT/;
+$cached_env_img{$key} = q|<IMG
+ WIDTH="15" HEIGHT="29" ALIGN="MIDDLE" BORDER="0"
+ SRC="|."$dir".q|img3.png"
+ ALT="$+$">|; 
+
 $key = q/longleftrightarrow;MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="20" HEIGHT="32" ALIGN="BOTTOM" BORDER="0"
- SRC="|."$dir".q|img14.png"
+ WIDTH="32" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
+ SRC="|."$dir".q|img15.png"
  ALT="$\longleftrightarrow $">|; 
 
 $key = q/P_1'^{-1};MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="138" HEIGHT="36" ALIGN="MIDDLE" BORDER="0"
- SRC="|."$dir".q|img21.png"
+ WIDTH="36" HEIGHT="36" ALIGN="MIDDLE" BORDER="0"
+ SRC="|."$dir".q|img22.png"
  ALT="$P_1'^{ -1}$">|; 
 
 $key = q/P_1'^{-1}P_2'longleftrightarrowP_2P_1^{-1};MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="110" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
- SRC="|."$dir".q|img20.png"
+ WIDTH="138" HEIGHT="36" ALIGN="MIDDLE" BORDER="0"
+ SRC="|."$dir".q|img21.png"
  ALT="$ P_1'^{ -1}
 P_2' \longleftrightarrow P_2 P_1^{ -1} $">|; 
 
 $key = q/(Longrightarrow);MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="19" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
- SRC="|."$dir".q|img17.png"
+ WIDTH="29" HEIGHT="14" ALIGN="BOTTOM" BORDER="0"
+ SRC="|."$dir".q|img18.png"
  ALT="\( \Longrightarrow \)">|; 
 
 $key = q/ddotfrown;MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="28" HEIGHT="15" ALIGN="BOTTOM" BORDER="0"
- SRC="|."$dir".q|img16.png"
+ WIDTH="19" HEIGHT="16" ALIGN="BOTTOM" BORDER="0"
+ SRC="|."$dir".q|img17.png"
  ALT="$\ddot\frown$">|; 
 
 $key = q/P_2P_1;MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="20" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
- SRC="|."$dir".q|img5.png"
+ WIDTH="38" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
+ SRC="|."$dir".q|img6.png"
  ALT="$P_2P_1$">|; 
 
 $key = q/{displaymath}(P_2P_1)^{-1}=P_1^{-1}P_2^{-1}.{displaymath};MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="41" HEIGHT="18" BORDER="0"
- SRC="|."$dir".q|img10.png"
+ WIDTH="146" HEIGHT="28" BORDER="0"
+ SRC="|."$dir".q|img11.png"
  ALT="\begin{displaymath}(P_2 P_1)^{ -1} = P_1^{ -1} P_2^{ -1}. \end{displaymath}">|; 
 
 $key = q/P_1parallelP_2;MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="38" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
- SRC="|."$dir".q|img6.png"
+ WIDTH="55" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
+ SRC="|."$dir".q|img7.png"
  ALT="$P_1\parallel P_2$">|; 
 
 $key = q/<;MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="31" HEIGHT="11" ALIGN="MIDDLE" BORDER="0"
+ WIDTH="15" HEIGHT="29" ALIGN="MIDDLE" BORDER="0"
  SRC="|."$dir".q|img1.png"
  ALT="$&lt;$">|; 
 
 $key = q/P_1';MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="338" HEIGHT="24" ALIGN="MIDDLE" BORDER="0"
- SRC="|."$dir".q|img12.png"
+ WIDTH="20" HEIGHT="32" ALIGN="MIDDLE" BORDER="0"
+ SRC="|."$dir".q|img13.png"
  ALT="$P_1'$">|; 
 
 $key = q/P_1;MSF=1.6;AAT/;
 $cached_env_img{$key} = q|<IMG
- WIDTH="15" HEIGHT="29" ALIGN="MIDDLE" BORDER="0"
- SRC="|."$dir".q|img3.png"
+ WIDTH="20" HEIGHT="30" ALIGN="MIDDLE" BORDER="0"
+ SRC="|."$dir".q|img4.png"
  ALT="$P_1$">|; 
 
 1;
