@@ -8,9 +8,9 @@ use Test::Darcs;
 use Shell::Command;
 use File::Compare;
 
-rm_rf  qw(temp1 temp2);
+cleanup qw(temp1 temp2);
 mkpath qw(temp1 temp2);
-END { rm_rf qw(temp1 temp2); }
+END { cleanup qw(temp1 temp2); }
 chdir 'temp1';
 darcs 'init';
 mkpath 'dir';
