@@ -1,12 +1,12 @@
 #!/bin/sh
 set -ev
 
-DARCS=$PWD/../darcs
+test $DARCS || DARCS=$PWD/../darcs
 
 rm -rf temp1 temp2
 mkdir temp1 temp2
 cd temp1
-$DARCS inittree
+$DARCS init
 touch foo bar
 $DARCS add foo bar
 $DARCS record -a -m add_foo_bar -A x
@@ -15,7 +15,8 @@ $DARCS mv bar foo
 $DARCS mv zig bar
 $DARCS record -a -m swap_foo_bar -A x
 cd ../temp2
-$DARCS inittree
+$DARCS init
 $DARCS pull -v -a ../temp1
 cd ..
 rm -rf temp1 temp2
+
