@@ -1,18 +1,19 @@
 #!/bin/sh
 set -ev
 
-DARCS=$PWD/../darcs
+test $DARCS || DARCS=$PWD/../darcs
 rm -rf temp1 temp2
 mkdir temp1 temp2
 cd temp1
-$DARCS inittree
+$DARCS init
 echo zig > foo
 $DARCS add foo
 #sleep 1
 $DARCS record -a -m add_foo -A x
 cd ../temp2
-$DARCS inittree
+$DARCS init
 $DARCS pull -a ../temp1
 cd ..
 cmp temp1/foo temp2/foo
 rm -rf temp1 temp2
+
