@@ -2,6 +2,8 @@
 
 # Some tests for 'darcs annotate'
 
+use lib 'lib/perl';
+use Test::Darcs;
 use Test::More qw/no_plan/;
 use strict;
 use vars qw/$DARCS/;
@@ -9,7 +11,7 @@ use vars qw/$DARCS/;
 die 'darcs not found' unless $ENV{DARCS} || (-x "$ENV{PWD}/../darcs");
 $DARCS = $ENV{DARCS} || "$ENV{PWD}/../darcs";
 
-`rm -rf temp1`;
+cleanup 'temp1';
 `mkdir temp1`;
 chdir 'temp1';
 `$DARCS init`;
