@@ -20,6 +20,6 @@ $DARCS add d/e
 $DARCS mv afile.txt d/e/afile.txt
 echo altered_text > d/e/afile.txt
 $DARCS record --author me --all --no-test --patch-name confusion
-test ! -f _darcs/current/afile.txt
+test ! -f _darcs/pristine/afile.txt
 echo y/d/y | tr / \\012 | $DARCS unrecord
-
+rm -rf $T
