@@ -33,7 +33,7 @@ cat temp | grep -v A | grep -v B | grep -v D | sed s/E/e/ \
 $DARCS record -m A
 cd ..
 
-darcs get tempOld tempB
+$DARCS get tempOld tempB
 cd tempB
 cp ../tempOld/_darcs/prefs/defaults _darcs/prefs
 echo 7 > foo
