@@ -1,11 +1,11 @@
 #!/bin/sh
 set -ev
 
-DARCS=$PWD/../darcs
+test $DARCS || DARCS=$PWD/../darcs
 rm -rf temp
 mkdir temp
 cd temp
-$DARCS inittree
+$DARCS init
 echo hi world > temp.c
 $DARCS add temp.c
 $DARCS record --all -A test --patch-name=hi
@@ -30,3 +30,4 @@ $DARCS whatsnew
 $DARCS record -a -m five -A ex
 cd ..
 rm -rf temp
+
