@@ -37,7 +37,7 @@ like($revert_output, qr/pending has conflicts/, 'darcs revert reports "pending h
 my $record_output =  darcs(qw/record -A x -a -m foo/);
 like($record_output, qr/pending has conflicts/, 'darcs record reports "pending has conflicts"');
 
-like( darcs('repair'), qr/The repo is already consistent, no changes made/i, 'darcs repair finds no problem');
+like( darcs('repair'), qr/The repository is already consistent, no changes made/i, 'darcs repair finds no problem');
 
 chdir '../';
 cleanup 'temp1';
