@@ -12,7 +12,7 @@ $DARCS add foo
 $DARCS record -a -m add -A x
 echo goodbye world >> foo
 echo y/y | tr / \\012 | $DARCS revert
-cmp foo _darcs/current/foo
+cmp foo _darcs/pristine/foo
 
 # Now let's test a trickier revert where changes commute nontrivially.
 
