@@ -19,7 +19,7 @@ cd ..
 $DARCS get --repo-name temp2 temp1
 cd temp2
 cp ../temp1/_darcs/prefs/defaults _darcs/prefs
-echo y | $DARCS unpull
+echo y/d/y | tr / \\012 | $DARCS unpull
 test -e foo -a ! -s foo
 echo hello >> foo
 $DARCS record -m mod_foo_again
