@@ -16,7 +16,7 @@ $DARCS diff -u
 $DARCS whatsnew
 $DARCS whatsnew --summary
 echo y | $DARCS revert -a
-cmp foo _darcs/current/foo
+cmp foo _darcs/pristine/foo
 cd ..
 rm -rf temp1
 
