@@ -14,14 +14,14 @@ mkdir d
 $DARCS add d
 $DARCS mv temp.c d/
 $DARCS record --all -A test --patch-name=mvetc
-cmp d/temp.c _darcs/current/d/temp.c
+cmp d/temp.c _darcs/pristine/d/temp.c
 
 echo y/d/y | tr / \\012 | $DARCS unrecord
 $DARCS whatsnew
-cmp d/temp.c _darcs/current/temp.c
+cmp d/temp.c _darcs/pristine/temp.c
 
 $DARCS record --all -A test --patch-name=again
-cmp d/temp.c _darcs/current/d/temp.c
+cmp d/temp.c _darcs/pristine/d/temp.c
 
 cd ..
 rm -rf temp
